diff --git a/src/renderer/components/Settings.tsx b/src/renderer/components/Settings.tsx
index b9ef4d6..77c29b9 100644
--- a/src/renderer/components/Settings.tsx
+++ b/src/renderer/components/Settings.tsx
@@ -16,6 +16,7 @@ import { isTruthy } from "shared/utils/guards";
export default function SettingsUi() {
const Settings = useSettings();
const supportsWindowsTransparency = VesktopNative.app.supportsWindowsTransparency();
+ const isWindows = process.platform === "win32";
const { autostart } = VesktopNative;
const [autoStartEnabled, setAutoStartEnabled] = useState(autostart.isEnabled());
@@ -100,6 +101,21 @@ export default function SettingsUi() {
Notification Badge
+ {!isWindows && (
+ <>
+ {
+ //just set it to a random value that isn't none to keep consistency with Windows
+ Settings.transparencyOption=v ? "acrylic":"none";
+ }}
+ note="Requires a full restart. You will need a theme that supports transparency for this to work."
+ >
+ Transparency
+
+ >
+ )}
+
{switches.map(([key, text, note, def, predicate]) => (
diff --git a/src/main/mainWindow.ts b/src/main/mainWindow.ts
index db44566..1ab70fd 100644
--- a/src/main/mainWindow.ts
+++ b/src/main/mainWindow.ts
@@ -370,6 +370,7 @@ function createMainWindow() {
const { frameless } = VencordSettings.store;
const noFrame = frameless === true || customTitleBar === true;
+ const isWindows = process.platform === "win32";
const win = (mainWin = new BrowserWindow({
show: false,
@@ -388,8 +389,8 @@ function createMainWindow() {
backgroundColor: "#00000000",
backgroundMaterial: transparencyOption
}),
- // Fix transparencyOption for custom discord titlebar
- ...(customTitleBar &&
+ // Fix transparencyOption for custom discord titlebar on Windows
+ ...((customTitleBar || !isWindows) &&
transparencyOption &&
transparencyOption !== "none" && {
transparent: true